<?php
/**
 * Created by PhpStorm.
 * User: zhuangxin
 * Date: 16-9-14
 * Time: 下午5:46
 */

namespace App\Article\v1\Controller;

use App\Article\Events\ArtAddEvent;
use App\Article\Validation\ArtValidator;
use App\Traits\Controller;
use App\Works\Events\ArtEditedEvent;
use Illuminate\Support\Facades\Event;
use Symfony\Component\HttpFoundation\Request;
use App\Article\Model\Art as ArtModel;
use App\Http\Response\Response;
use App\Http\Response\HttpStatus;

class Article extends \Illuminate\Routing\Controller
{

    use Controller;

    protected $query_fields = [
        "uid","title","is_del","type"
    ];

    public function index()
    {
        $query = request()->query();
        $where = $this->filter($query);
        $where = $this->setBlurSearch($where,"title");
        is_null($where) && $where = [];
        $row  = isset($query["size"])?$query["size"]:config("app.default_perpage");
        return Response::success(ArtModel::where($where)->paginate($row)->toArray());
    }

    public function store(Request $request)
    {
        $validator = new ArtValidator();
        $post = $request->all();
        $res = $validator->validate($post);
        if ($res->fails()) {
            $messages = $validator->getMessages();
            return Response::error($messages,HttpStatus::HttpValidationFailed);
        }
        $this->csrf($post,'content');
        $model = ArtModel::newArt($post);
        var_dump($model);
        if ($model !== false) {
            Event::fire(new ArtAddEvent($model));
            return Response::ok();
        } else {
            return Response::error();
        }
    }

    public function update($id,Request $request)
    {
        try {
            $model = ArtModel::findOrFail($id, ["id"]);
            $post = $request->all();
            $validator = new ArtValidator();
            $res = $validator->validate($post);
            if ($res->fails()) {
                $messages = $validator->getMessages();
                return Response::error($messages,HttpStatus::HttpValidationFailed);
            }
            $post['content'] = $this->csrf($post,'content');
            $model->uptArt($post);
            if ($model !== false) {
                Event::fire(new ArtEditedEvent($model));
                return Response::ok();
            } else {
                return Response::error();
            }
        } catch (ModelNotFoundException $e){
            return Response::error(HttpStatus::HttpNotFound,"攻略未找到");
        }
    }

    public function show($id)
    {
        try {
            $info = ArtModel::findOrFail($id);
            $info->getRelate(request("relation"));
            return Response::success($info->toArray());
        } catch (ModelNotFoundException $e){
            return Response::error(HttpStatus::HttpNotFound,"攻略未找到");
        }
    }

    public function getRelate($id,$relation)
    {
        try {
            $model = ArtModel::findOrFail($id , ["id"]);
            $model->getRelate($relation);
            return Response::success($model);
        } catch (ModelNotFoundException $e){
            return Response::error(HttpStatus::HttpNotFound,"攻略未找到");
        }
    }
}